<?php
namespace Raabeschule\Sidebar;

$metaboxes = array(
        'sidebar' => array(
                'title' => __('Sidebar', 'raabeschule'),
                'applicableto' => 'page',
                'location' => 'normal',
                'display_condition' => array('templates/page_template_sidebar.php', 'templates/page_template_topics_sidebar.php'),
                'priority' => 'high',
                'fields' => array(
                        'sidebar_title' => array(
                                'type' => 'text',
                                'title' => __('Title', 'raabeschule')
                        ),
                        'sidebar_body' => array(
                                'type' => 'wp_editor'
                        )
                )
        )
);

add_action( 'admin_init', __NAMESPACE__ . '\\add_metaboxes' );

function add_metaboxes() {
  global $metaboxes;

  if(!empty($metaboxes)) {
    foreach($metaboxes as $id => $metabox) {
      add_meta_box($id, $metabox['title'], __NAMESPACE__ . '\\show_metaboxes', $metabox['applicableto'], $metabox['location'], $metabox['priority'], $id);
    }
  }
}

function show_metaboxes($post, $args) {
  global $metaboxes;

  $fields = $metaboxes[$args['id']]['fields'];
  $custom = get_post_custom( $post->ID );
  wp_nonce_field(plugin_basename( __FILE__ ), 'raabeschule_nonce');

  foreach($fields as $id => $field) {
    if($field['type'] == 'wp_editor') {
      wp_editor((isset($custom[$id][0]) ? $custom[$id][0] : ''), $id);
    } elseif($field['type'] == 'text') {
      echo '<label style="font-w" for="' . $id . '"><strong>' . $field['title'] . '</strong></label><br><input style="width: 100%; height: 40px; font-size: 18px; margin-bottom: 10px;" type="text" id="' . $id . '" name="' . $id . '" value="' . (isset($custom[$id][0]) ? $custom[$id][0] : '') . '"><br>';
    }
  }
}

add_action( 'save_post', __NAMESPACE__ . '\\save_metaboxes' );

function save_metaboxes( $post_id ) {
  global $metaboxes;

  if (!wp_verify_nonce( $_POST['raabeschule_nonce'], plugin_basename( __FILE__ )))
    return $post_id;

  if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
    return $post_id;

  if ( 'page' == $_POST['post_type'] ) {
    if ( ! current_user_can( 'edit_page', $post_id ) )
      return $post_id;
  } elseif ( ! current_user_can( 'edit_post', $post_id ) ) {
    return $post_id;
  }

  $post_type = get_post_type();

  foreach ( $metaboxes as $id => $metabox ) {
    if($metabox['applicableto'] == $post_type ) {
      $fields = $metaboxes[$id]['fields'];
      foreach ( $fields as $id => $field ) {
        $old = get_post_meta( $post_id, $id, true );
        $new = $_POST[$id];

        if ( $new && $new != $old ) {
          update_post_meta( $post_id, $id, $new );
        }
        elseif ( '' == $new && $old || ! isset( $_POST[$id] ) ) {
          delete_post_meta( $post_id, $id, $old );
        }
      }
    }
  }
}

add_action('admin_print_scripts', __NAMESPACE__ . '\\display_metaboxes', 1000);

function display_metaboxes($hook) {
  global $metaboxes;

  if($hook != 'post.php' && get_post_type() == 'page') { ?>
    <script type="text/javascript">// <![CDATA[
      $ = jQuery;

      <?php
      $formats = $ids = array();
      foreach ( $metaboxes as $id => $metabox ) {
        foreach($metabox['display_condition'] as $condition) {
          array_push( $formats, "'" . $condition . "': '" . $id . "'" );
        }
        array_push( $ids, "#" . $id );
      }
      ?>
      var formats = { <?php echo implode( ',', $formats );?> };
      var ids = "<?php echo implode( ',', $ids ); ?>";
      function displayMetaboxes() {
        $(ids).hide();
        var selectedElt = $("select[name='page_template']").val();

        if ( formats[selectedElt] )
          $("#" + formats[selectedElt]).fadeIn();
      }

      $(function() {
        displayMetaboxes();

        $("select[name='page_template']").change(function() {
          displayMetaboxes();
        });
      });
      // ]]></script>
    <?php
  }
}
